summaryrefslogtreecommitdiff
path: root/src/mongo/db/catalog/index_catalog_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/catalog/index_catalog_impl.h')
-rw-r--r--src/mongo/db/catalog/index_catalog_impl.h14
1 files changed, 5 insertions, 9 deletions
diff --git a/src/mongo/db/catalog/index_catalog_impl.h b/src/mongo/db/catalog/index_catalog_impl.h
index fb3ec499a0d..fa195004756 100644
--- a/src/mongo/db/catalog/index_catalog_impl.h
+++ b/src/mongo/db/catalog/index_catalog_impl.h
@@ -95,19 +95,15 @@ public:
bool includeUnfinishedIndexes = false) const override;
/**
* Find index by matching key pattern and collation spec. The key pattern and collation spec
* uniquely identify an index.
*
- * Collation is specified as a normalized collation spec as returned by
- * CollationInterface::getSpec. An empty object indicates the simple collation.
- *
- * @return null if cannot find index, otherwise the index with a matching key pattern and
- * collation.
+ * @return null if cannot find index, otherwise the index with a matching signature.
*/
- const IndexDescriptor* findIndexByKeyPatternAndCollationSpec(
+ const IndexDescriptor* findIndexByKeyPatternAndOptions(
OperationContext* opCtx,
const BSONObj& key,
- const BSONObj& collationSpec,
+ const BSONObj& indexSpec,
bool includeUnfinishedIndexes = false) const override;
/**
@@ -95,19 +95,15 @@ public:
bool includeUnfinishedIndexes = false) const override;
/**
- * Find index by matching key pattern and collation spec. The key pattern and collation spec
- * uniquely identify an index.
+ * Find index by matching key pattern and options. The key pattern, collation spec, and partial
+ * filter expression together uniquely identify an index.
*